import { OnChanges, SimpleChanges, ElementRef, AfterContentInit, EventEmitter, QueryList, AfterViewInit } from "@angular/core";
import * as GC from "@grapecity/inputman";
declare type ComboBoxValuesType = number[] | string[] | boolean[] | object[];
declare type ComboBoxItemType = string | object;
declare type ComboBoxItemsType = string[] | object[];
export declare function Property(setter?: string, getter?: string, isPramArr?: boolean, supportWithinConfig?: boolean, order?: number): Function;
export interface PropertyDictionary {
    [propertyName: string]: PropertyMethod;
}
export interface PropertyMethod {
    getter: string;
    setter: string;
    isPramArr: boolean;
    supportWithinConfig: boolean;
    order: number;
}
export declare enum MethodType {
    getter = 0,
    setter = 1
}
export declare function provideParent(component: any): {
    provide: typeof GcComponents;
    useExisting: import("@angular/core").Type<any>;
};
export declare abstract class GcComponents<T extends object> implements OnChanges, AfterContentInit {
    protected _container: Element;
    protected _imCtrl: T;
    propDic: PropertyDictionary;
    constructor(ref: ElementRef);
    ngOnChanges(changes: SimpleChanges): void;
    private setValueToIMControl;
    ngAfterContentInit(): void;
    protected abstract initGcComponent(): void;
    protected abstract bindEvent(): void;
    private tryGetPropertyOperator;
    private hasRealMethod;
    getNestedIMControl(): T;
    onInitialized: EventEmitter<object>;
}
export declare abstract class GcInputManBaseComponent<T extends GC.InputMan.GcInputManBase> extends GcComponents<T> {
    visible: boolean;
    enabled: boolean;
    readOnly: boolean;
    exitOnLeftRightKey: GC.InputMan.ExitOnLeftRightKey;
    editMode: GC.InputMan.EditMode;
    watermarkDisplayNullText: string | null;
    watermarkNullText: string | null;
    acceptsCrlf: GC.InputMan.CrLfMode;
    useClipboard: boolean;
    exitOnEnterKey: GC.InputMan.ExitKey;
    container: HTMLElement;
    autoDropDown: boolean;
    dropDownButtonVisible: boolean;
    autoScale: boolean;
    minScaleFactor: number;
    onEditStatusChanged: EventEmitter<object>;
    onInvalidInput: EventEmitter<object>;
    onKeyExit: EventEmitter<object>;
    onTextChanged: EventEmitter<object>;
    onInput: EventEmitter<object>;
    onFocusOut: EventEmitter<object>;
    onKeyDown: EventEmitter<object>;
    onKeyUp: EventEmitter<object>;
    onSyncValueToOriginalInput: EventEmitter<object>;
    textChange: EventEmitter<string>;
    protected bindEvent(): void;
}
export declare class GcTextBoxComponent extends GcInputManBaseComponent<GC.InputMan.GcTextBox> {
    constructor(ref: ElementRef);
    autoConvert: boolean;
    ellipsisString: string | null;
    ellipsis: GC.InputMan.EllipsisMode;
    format: string | null;
    lengthAsByte: boolean;
    maxLength: number;
    passwordChar: string | null;
    text: string | null;
    useSystemPasswordChar: boolean;
    imeReadingStringAppend: boolean;
    imeReadingStringKanaMode: GC.InputMan.KanaMode;
    imeReadingStringEnableAlphabetReadingMapping: boolean;
    exitOnLastChar: boolean;
    highlightText: boolean;
    imeReadingString: string;
    showClearButton: boolean;
    passwordRevelationMode: GC.InputMan.PasswordRevelationMode;
    onIMEReadingStringOutput: EventEmitter<object>;
    imeReadingStringChange: EventEmitter<string>;
    protected initGcComponent(): void;
    protected bindEvent(): void;
}
export declare class GcNumberComponent extends GcInputManBaseComponent<GC.InputMan.GcNumber> {
    constructor(ref: ElementRef);
    value: number | string | null;
    text: string | null;
    watermarkZeroText: string | null;
    formatDigit: string | null;
    displayPositivePrefix: string | null;
    displayFormatDigit: string | null;
    maxValue: number | string | null;
    minValue: number | string | null;
    positivePrefix: string | null;
    positiveSuffix: string | null;
    displayPositiveSuffix: string | null;
    negativePrefix: string | null;
    displayNegativePrefix: string | null;
    negativeSuffix: string | null;
    displayNegativeSuffix: string | null;
    valueSign: GC.InputMan.ValueSign;
    adjustValueOnFocus: boolean;
    allowDeleteToNull: boolean;
    clearAction: GC.InputMan.ClearModeAction;
    acceptsDecimal: GC.InputMan.DecimalMode;
    currencySymbol: string | null;
    decimalPoint: string | null;
    maxMinBehavior: GC.InputMan.MaxMinBehavior;
    separator: string | null;
    watermarkDisplayZeroText: string | null;
    highlightText: boolean;
    allowSpin: boolean;
    spinWheel: boolean;
    spinOnKeys: boolean;
    spinWrap: boolean;
    showSpinButton: boolean;
    spinButtonPosition: GC.InputMan.SpinButtonAlignment;
    showNumericPad: boolean;
    numericPadPosition: GC.InputMan.DropDownButtonAlignment;
    showClearButton: boolean;
    onSpinDown: EventEmitter<object>;
    onSpinUp: EventEmitter<object>;
    onInvalidRange: EventEmitter<object>;
    onValueChanged: EventEmitter<object>;
    valueChange: EventEmitter<number>;
    protected initGcComponent(): void;
    protected bindEvent(): void;
    clear(): void;
}
export declare class GcDateTimeComponent extends GcInputManBaseComponent<GC.InputMan.GcDateTime> {
    constructor(ref: ElementRef);
    protected initGcComponent(): void;
    text: string | null;
    number: number;
    maxDate: Date | string | null;
    minDate: Date | string | null;
    formatPattern: string | null;
    spinIncrement: number;
    spinOnKeys: boolean;
    spinWrap: boolean;
    allowSpin: boolean;
    spinWheel: boolean;
    displayFormatPattern: string | null;
    watermarkEmptyEraText: string | null;
    promptChar: string | null;
    AMDesignator: string | null;
    PMDesignator: string | null;
    twoDigitYearMax: number;
    hour12Mode: GC.InputMan.Hour12Mode;
    tabAction: GC.InputMan.TabAction;
    maxMinBehavior: GC.InputMan.MaxMinBehavior;
    midnightAs24: boolean;
    showLiterals: GC.InputMan.ShowLiterals;
    adjustValueOnFocus: boolean;
    useTwoDigitYearMax: boolean;
    validateMode: GC.InputMan.ValidateMode;
    clipContent: GC.InputMan.ClipContent;
    value: Date | string;
    watermarkDisplayEmptyEraText: string | null;
    dropDownConfig: GC.InputMan.GcDateTimeDropDownConfig;
    exitOnLastChar: boolean;
    highlightText: GC.InputMan.HighlightText;
    showSpinButton: boolean;
    spinButtonPosition: string | null;
    showDropDownButton: boolean;
    dropDownButtonAlignment: string | null;
    showClearButton: boolean;
    onSpinDown: EventEmitter<object>;
    onSpinUp: EventEmitter<object>;
    onInvalidRange: EventEmitter<object>;
    onInvalidValue: EventEmitter<object>;
    onNumberChanged: EventEmitter<object>;
    onValueChanged: EventEmitter<object>;
    numberChange: EventEmitter<number>;
    valueChange: EventEmitter<Date>;
    protected bindEvent(): void;
}
export declare class GcCalendarComponent extends GcComponents<GC.InputMan.GcCalendar> {
    constructor(ref: ElementRef);
    protected initGcComponent(): void;
    visible: boolean;
    maxSelectionCount: number;
    selectionMode: GC.InputMan.CalendarSelectionMode;
    selectedDate: Date | null;
    enabled: boolean;
    weekTitleSelect: boolean;
    weekNumberSelect: boolean;
    focusDate: Date | null;
    maxDate: Date | null;
    minDate: Date | null;
    allowSelection: GC.InputMan.AllowSelection;
    emptyRows: GC.InputMan.EmptyRows;
    firstDayOfWeek: GC.InputMan.DayOfWeek;
    firstFiscalMonth: GC.InputMan.Months;
    firstMonthInView: GC.InputMan.Months;
    yearMonthFormat: string;
    headerFormat: string;
    showZoomButton: boolean;
    showRokuyou: GC.InputMan.Rokuyou;
    showHeader: boolean;
    showToday: boolean;
    showWeekNumber: boolean;
    showTrailing: boolean;
    calendarYear: GC.InputMan.CalendarYear;
    showNavigator: GC.InputMan.CalendarNavigators;
    navigatorOrientation: string;
    overrideTipText: string;
    calendarType: GC.InputMan.CalendarType;
    calendarDimensions: Array<number>;
    onClickDate: EventEmitter<object>;
    onScrolled: EventEmitter<object>;
    onFocusDateChanged: EventEmitter<object>;
    onSelectedDateChanged: EventEmitter<object>;
    focusDateChange: EventEmitter<object>;
    selectedDateChange: EventEmitter<object>;
    protected bindEvent(): void;
}
export declare class GcMaskComponent extends GcInputManBaseComponent<GC.InputMan.GcMask> {
    constructor(ref: ElementRef);
    autoConvert: boolean;
    value: string | null;
    formatPattern: string;
    promptChar: string;
    showLiterals: GC.InputMan.ShowLiterals;
    tabAction: GC.InputMan.TabAction;
    text: string;
    clipContent: GC.InputMan.ClipContent;
    allowSpin: boolean;
    spinWheel: boolean;
    spinOnKeys: boolean;
    exitOnLastChar: boolean;
    highlightText: string;
    showSpinButton: boolean;
    spinButtonPosition: GC.InputMan.SpinButtonAlignment;
    valueIsFull: boolean;
    showClearButton: boolean;
    onTextChanging: EventEmitter<object>;
    onSpinDown: EventEmitter<object>;
    onSpinUp: EventEmitter<object>;
    onValueChanged: EventEmitter<object>;
    valueChange: EventEmitter<string>;
    valueIsFullChange: EventEmitter<boolean>;
    protected initGcComponent(): void;
    protected bindEvent(): void;
}
export declare class GcListBoxColumnComponent {
    name: string;
    label: string;
    width: number | string;
    isValuePath: boolean;
    visible: boolean;
    clickSort: boolean;
    contentAlignment: GC.InputMan.Alignment;
    headerAlignment: GC.InputMan.Alignment;
    showTip: boolean;
}
export declare class GcListBoxComponent extends GcComponents<GC.InputMan.GcListBox> {
    constructor(ref: ElementRef);
    items: Array<object>;
    columns: Array<GC.InputMan.ColumnConfig>;
    virtualMode: boolean;
    allowResize: boolean;
    selectionMode: string;
    selectedIndex: number;
    checkedIndex: number;
    selectedIndices: number[];
    checkedIndices: number[];
    allowColumnResize: boolean;
    overflow: string;
    width: number;
    height: number;
    itemHeight: number;
    checkOnClick: boolean;
    visibleItems: number;
    visible: boolean;
    enabled: boolean;
    showTip: boolean;
    multiColumn: boolean;
    colHeaderHeight: number;
    showHeader: boolean;
    valueMemberPath: string;
    displayMemberPath: string;
    showCheckBox: boolean;
    itemTemplate: string | string[];
    headerTemplate: string;
    footerTemplate: string;
    emptyTemplate: string;
    load: Function;
    pageSize: number;
    generatingItem: (args: GC.InputMan.IItemGeneratingArgs) => void;
    selectTemplate: (args: GC.InputMan.ITemplateSelectArgs) => string;
    formatItem: (args: GC.InputMan.IItemArgs) => void;
    checkedChanged: EventEmitter<object>;
    selectedChanged: EventEmitter<object>;
    focusedChanged: EventEmitter<object>;
    itemClick: EventEmitter<object>;
    loadComplete: EventEmitter<object>;
    itemsChanged: EventEmitter<object>;
    selectedIndexChange: EventEmitter<number>;
    checkedIndexChange: EventEmitter<number>;
    selectedIndicesChange: EventEmitter<object>;
    checkedIndicesChange: EventEmitter<object>;
    columnComponents: QueryList<GcListBoxColumnComponent>;
    protected initGcComponent(): void;
    protected bindEvent(): void;
}
export declare class GcComboBoxColumnComponent {
    name: string;
    label: string;
    width: number | string;
    isValuePath: boolean;
    visible: boolean;
    clickSort: boolean;
    contentAlignment: GC.InputMan.Alignment;
    headerAlignment: GC.InputMan.Alignment;
    showTip: boolean;
}
export declare class GcComboBoxComponent extends GcComponents<GC.InputMan.GcComboBox> {
    constructor(ref: ElementRef);
    items: Array<object>;
    selectedValue: object;
    allowDropDownResize: boolean;
    readOnly: boolean;
    autoSelect: boolean;
    selectedIndex: number;
    autoFilter: string;
    visible: boolean;
    enabled: boolean;
    showTip: boolean;
    isEditable: boolean;
    watermarkDisplayNullText: string;
    watermarkNullText: string;
    highlightText: boolean;
    exitOnEnterKey: string;
    useClipboard: boolean;
    acceptsCrlf: string;
    ellipsis: string;
    ellipsisString: string;
    exitOnLeftRightKey: string;
    editMode: string;
    checkedValues: ComboBoxValuesType;
    selectedItem: ComboBoxItemType;
    checkedItems: ComboBoxItemsType;
    checkedIndices: number[];
    showDropDownButton: boolean;
    dropDownButtonPosition: string;
    showSpinButton: boolean;
    spinButtonPosition: string;
    dropDownWidth: number;
    dropDownHeight: number;
    minPrefixLength: number;
    isMultiSelect: boolean;
    dropDownOverflow: string;
    visibleItems: number;
    itemHeight: number;
    columns: GC.InputMan.ColumnConfig[];
    showHeader: boolean;
    valueMemberPath: string;
    displayMemberPath: string;
    checkOnClick: boolean;
    itemTemplate: string | string[];
    headerTemplate: string;
    footerTemplate: string;
    spinWheel: boolean;
    emptyTemplate: string;
    load: Function;
    pageSize: number;
    virtualMode: boolean;
    generatingItem: (args: GC.InputMan.IItemGeneratingArgs) => void;
    selectTemplate: (args: GC.InputMan.ITemplateSelectArgs) => string;
    formatItem: (args: GC.InputMan.IItemArgs) => void;
    allowColumnResize: boolean;
    colHeaderHeight: number;
    container: HTMLElement;
    autoDropDown: boolean;
    dropDownButtonVisible: boolean;
    showClearButton: boolean;
    autoScale: boolean;
    minScaleFactor: number;
    selectedChanged: EventEmitter<object>;
    checkedChanged: EventEmitter<object>;
    dropDownClosed: EventEmitter<object>;
    dropDownOpened: EventEmitter<object>;
    textChanged: EventEmitter<object>;
    spinDown: EventEmitter<object>;
    spinUp: EventEmitter<object>;
    itemsChanged: EventEmitter<object>;
    itemsChange: EventEmitter<object>;
    selectedValueChange: EventEmitter<object | string | number | boolean>;
    selectedIndexChange: EventEmitter<number>;
    checkedValuesChange: EventEmitter<object>;
    selectedItemChange: EventEmitter<object | string>;
    checkedItemsChange: EventEmitter<object>;
    checkedIndicesChange: EventEmitter<object>;
    columnComponents: QueryList<GcComboBoxColumnComponent>;
    protected initGcComponent(): void;
    protected bindEvent(): void;
}
export declare class GcDateTimePickerComponent extends GcComponents<GC.InputMan.GcDateTimePicker> {
    constructor(ref: ElementRef);
    selectedValue: Date;
    maxDate: Date;
    minDate: Date;
    type: GC.InputMan.PickerType;
    minuteInterval: GC.InputMan.Interval;
    secondsInterval: GC.InputMan.Interval;
    visible: boolean;
    hasSeconds: string;
    showMidnightAs24: string;
    yearFormat: Function;
    monthFormat: Function;
    dayFormat: Function;
    selectedDateChanged: EventEmitter<object>;
    selectedValueChange: EventEmitter<object>;
    protected initGcComponent(): void;
    protected bindEvent(): void;
}
export declare class GcTipNotifierComponent extends GcComponents<GC.InputMan.GcTipNotifier> implements AfterViewInit {
    private _parent;
    ngAfterViewInit(): void;
    protected bindEvent(): void;
    constructor(ref: ElementRef, _parent: GcComponents<GC.InputMan.GcInputManBase | GC.InputMan.GcComboBox>);
    direction: string;
    position: string;
    directionPriority: Array<GC.InputMan.TipDirection>;
    template: string;
    failMessage: string;
    successMessage: string;
    tipState: string;
    protected initGcComponent(): void;
    onFail(): void;
    onSuccess(): void;
    onClear(): void;
}
export declare class GcIconNotifierComponent extends GcComponents<GC.InputMan.GcIconNotifier> implements AfterViewInit {
    private _parent;
    ngAfterViewInit(): void;
    protected bindEvent(): void;
    constructor(ref: ElementRef, _parent: GcComponents<GC.InputMan.GcInputManBase | GC.InputMan.GcComboBox>);
    direction: GC.InputMan.IconDirection;
    failIcon: string;
    successIcon: string;
    failMessage: string;
    successMessage: string;
    protected initGcComponent(): void;
    onFail(): void;
    onSuccess(): void;
    onClear(): void;
}
export declare class GcMultilineTextBoxComponent extends GcInputManBaseComponent<GC.InputMan.GcMultiLineTextBox> {
    constructor(ref: ElementRef);
    countWrappedLine: boolean;
    lengthAsByte: boolean;
    maxLength: number;
    maxLineCount: number;
    imeReadingStringKanaMode: GC.InputMan.KanaMode;
    scrollBarMode: GC.InputMan.ScrollBarMode;
    scrollBars: GC.InputMan.ScrollBars;
    wordWrap: boolean;
    acceptsReturn: boolean;
    acceptsTab: boolean;
    imeReadingStringAppend: boolean;
    height: number;
    imeReadingStringEnableAlphabetReadingMapping: boolean;
    exitOnLastChar: boolean;
    highlightText: boolean;
    format: string;
    autoConvert: boolean;
    text: string;
    lines: Array<string>;
    imeReadingString: string;
    onEditStatusChanged: EventEmitter<object>;
    onInvalidInput: EventEmitter<object>;
    onKeyExit: EventEmitter<object>;
    onTextChanged: EventEmitter<object>;
    onIMEReadingStringOutput: EventEmitter<object>;
    textChange: EventEmitter<string>;
    imeReadingStringChange: EventEmitter<string>;
    protected initGcComponent(): void;
    protected bindEvent(): void;
}
export {};
