import { __decorate, __extends, __param } from 'tslib';
import { forwardRef, EventEmitter, Output, Input, ElementRef, Component, ContentChildren, Optional, NgModule } from '@angular/core';
import { InputMan } from '@grapecity/inputman';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

function Property(setter, getter, isPramArr, supportWithinConfig, order) {
    var saveToTargetProDic = function (target, propertyName) {
        var methods = {
            setter: setter,
            getter: getter,
            isPramArr: isPramArr,
            supportWithinConfig: (typeof supportWithinConfig === "boolean") ? supportWithinConfig : true,
            order: (typeof order === "number") ? order : -1
        };
        if (!target.propDic) {
            target.propDic = {};
        }
        target.propDic[propertyName] = methods;
    };
    return saveToTargetProDic;
}
var isEmpty = function (value) {
    return value === undefined || value === null || value === "";
};
var ɵ0 = isEmpty;
var getMethodPrefix = function (type) {
    if (type === MethodType.getter) {
        return "get";
    }
    else if (type === MethodType.setter) {
        return "set";
    }
};
var ɵ1 = getMethodPrefix;
var MethodType;
(function (MethodType) {
    MethodType[MethodType["getter"] = 0] = "getter";
    MethodType[MethodType["setter"] = 1] = "setter";
})(MethodType || (MethodType = {}));
function provideParent(component) {
    return { provide: GcComponents, useExisting: forwardRef(function () { return component; }) };
}
var GcComponents = /** @class */ (function () {
    function GcComponents(ref) {
        this.onInitialized = new EventEmitter();
        this._container = ref.nativeElement;
    }
    GcComponents.prototype.ngOnChanges = function (changes) {
        var _this = this;
        if (!this._imCtrl) {
            return;
        }
        Object.keys(changes).forEach(function (key) {
            var currentValue = changes[key].currentValue;
            _this.setValueToIMControl(key, currentValue);
        });
    };
    GcComponents.prototype.setValueToIMControl = function (key, value) {
        if (value === undefined) {
            return;
        }
        var setter = this.tryGetPropertyOperator(key, MethodType.setter);
        if (this.hasRealMethod(setter)) {
            if (this.propDic && this.propDic[key] && this.propDic[key].isPramArr === true) {
                this._imCtrl[setter].apply(this._imCtrl, value);
            }
            else {
                this._imCtrl[setter](value);
            }
        }
    };
    GcComponents.prototype.ngAfterContentInit = function () {
        var _this = this;
        this.initGcComponent();
        if (typeof this._imCtrl === 'object') {
            this.onInitialized.emit(this._imCtrl);
        }
        this.bindEvent();
        if (this.propDic) {
            var unSupportWithinConfigProps = Object.keys(this.propDic).filter(function (p) { return _this.propDic[p] && _this.propDic[p].supportWithinConfig === false; });
            unSupportWithinConfigProps.sort(function (p1, p2) {
                return _this.propDic[p1].order - _this.propDic[p2].order;
            });
            unSupportWithinConfigProps.forEach(function (p) {
                _this.setValueToIMControl(p, _this[p]);
            });
        }
    };
    GcComponents.prototype.tryGetPropertyOperator = function (propertyName, methodType) {
        var method = "";
        if (this.propDic && this.propDic[propertyName]) {
            method = methodType === MethodType.getter ? this.propDic[propertyName].getter : this.propDic[propertyName].setter;
            if (!isEmpty(method)) {
                return method;
            }
        }
        return getMethodPrefix(methodType) + propertyName[0].toUpperCase() + propertyName.slice(1);
    };
    GcComponents.prototype.hasRealMethod = function (methodName) {
        return this._imCtrl && typeof this._imCtrl[methodName] === "function";
    };
    GcComponents.prototype.getNestedIMControl = function () {
        return this._imCtrl;
    };
    __decorate([
        Output()
    ], GcComponents.prototype, "onInitialized", void 0);
    return GcComponents;
}());
var GcInputManBaseComponent = /** @class */ (function (_super) {
    __extends(GcInputManBaseComponent, _super);
    function GcInputManBaseComponent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.onEditStatusChanged = new EventEmitter();
        _this.onInvalidInput = new EventEmitter();
        _this.onKeyExit = new EventEmitter();
        _this.onTextChanged = new EventEmitter();
        _this.onInput = new EventEmitter();
        _this.onFocusOut = new EventEmitter();
        _this.onKeyDown = new EventEmitter();
        _this.onKeyUp = new EventEmitter();
        _this.onSyncValueToOriginalInput = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        _this.textChange = new EventEmitter();
        return _this;
    }
    GcInputManBaseComponent.prototype.bindEvent = function () {
        var _this = this;
        if (!this._imCtrl) {
            return;
        }
        this._imCtrl.onEditStatusChanged(function (s) { _this.onEditStatusChanged.emit(s); });
        this._imCtrl.onInvalidInput(function (s) { _this.onInvalidInput.emit(s); });
        this._imCtrl.onKeyExit(function (s) { _this.onKeyExit.emit(s); });
        this._imCtrl.onTextChanged(function (s) { _this.onTextChanged.emit(s); _this.textChange.emit(s.getText()); });
        this._imCtrl.onInput(function (s) { _this.onInput.emit(s); });
        this._imCtrl.onFocusOut(function (s) { _this.onFocusOut.emit({ sender: s }); });
        this._imCtrl.onKeyDown(function (s) { _this.onKeyDown.emit({ sender: s }); });
        this._imCtrl.onKeyUp(function (s) { _this.onKeyUp.emit({ sender: s }); });
        this._imCtrl.onSyncValueToOriginalInput(function (v, e) { _this.onSyncValueToOriginalInput.emit({ value: v, element: e }); });
    };
    __decorate([
        Input()
    ], GcInputManBaseComponent.prototype, "visible", void 0);
    __decorate([
        Input()
    ], GcInputManBaseComponent.prototype, "enabled", void 0);
    __decorate([
        Input()
    ], GcInputManBaseComponent.prototype, "readOnly", void 0);
    __decorate([
        Input()
    ], GcInputManBaseComponent.prototype, "exitOnLeftRightKey", void 0);
    __decorate([
        Input()
    ], GcInputManBaseComponent.prototype, "editMode", void 0);
    __decorate([
        Input()
    ], GcInputManBaseComponent.prototype, "watermarkDisplayNullText", void 0);
    __decorate([
        Input()
    ], GcInputManBaseComponent.prototype, "watermarkNullText", void 0);
    __decorate([
        Input()
    ], GcInputManBaseComponent.prototype, "acceptsCrlf", void 0);
    __decorate([
        Input()
    ], GcInputManBaseComponent.prototype, "useClipboard", void 0);
    __decorate([
        Input()
    ], GcInputManBaseComponent.prototype, "exitOnEnterKey", void 0);
    __decorate([
        Input()
    ], GcInputManBaseComponent.prototype, "container", void 0);
    __decorate([
        Input()
    ], GcInputManBaseComponent.prototype, "autoDropDown", void 0);
    __decorate([
        Input()
    ], GcInputManBaseComponent.prototype, "dropDownButtonVisible", void 0);
    __decorate([
        Input()
    ], GcInputManBaseComponent.prototype, "autoScale", void 0);
    __decorate([
        Input()
    ], GcInputManBaseComponent.prototype, "minScaleFactor", void 0);
    __decorate([
        Output()
    ], GcInputManBaseComponent.prototype, "onEditStatusChanged", void 0);
    __decorate([
        Output()
    ], GcInputManBaseComponent.prototype, "onInvalidInput", void 0);
    __decorate([
        Output()
    ], GcInputManBaseComponent.prototype, "onKeyExit", void 0);
    __decorate([
        Output()
    ], GcInputManBaseComponent.prototype, "onTextChanged", void 0);
    __decorate([
        Output()
    ], GcInputManBaseComponent.prototype, "onInput", void 0);
    __decorate([
        Output()
    ], GcInputManBaseComponent.prototype, "onFocusOut", void 0);
    __decorate([
        Output()
    ], GcInputManBaseComponent.prototype, "onKeyDown", void 0);
    __decorate([
        Output()
    ], GcInputManBaseComponent.prototype, "onKeyUp", void 0);
    __decorate([
        Output()
    ], GcInputManBaseComponent.prototype, "onSyncValueToOriginalInput", void 0);
    __decorate([
        Output()
    ], GcInputManBaseComponent.prototype, "textChange", void 0);
    return GcInputManBaseComponent;
}(GcComponents));
var GcTextBoxComponent = /** @class */ (function (_super) {
    __extends(GcTextBoxComponent, _super);
    function GcTextBoxComponent(ref) {
        var _this = _super.call(this, ref) || this;
        _this.onIMEReadingStringOutput = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        _this.imeReadingStringChange = new EventEmitter();
        return _this;
    }
    GcTextBoxComponent_1 = GcTextBoxComponent;
    GcTextBoxComponent.prototype.initGcComponent = function () {
        var input = document.createElement("input");
        this._container.appendChild(input);
        this["IMEReadingStringAppend"] = this.imeReadingStringAppend;
        this["IMEReadingStringKanaMode"] = this.imeReadingStringKanaMode;
        this["IMEReadingStringEnableAlphabetReadingMapping"] = this.imeReadingStringEnableAlphabetReadingMapping;
        this._imCtrl = new InputMan.GcTextBox(input, this);
    };
    GcTextBoxComponent.prototype.bindEvent = function () {
        var _this = this;
        if (!this._imCtrl) {
            return;
        }
        _super.prototype.bindEvent.call(this);
        this._imCtrl.onIMEReadingStringOutput(function (s, e) {
            _this.onIMEReadingStringOutput.emit({ sender: s, eArgs: e });
            _this.imeReadingStringChange.emit(s.getIMEReadingString());
        });
    };
    var GcTextBoxComponent_1;
    GcTextBoxComponent.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    __decorate([
        Input()
    ], GcTextBoxComponent.prototype, "autoConvert", void 0);
    __decorate([
        Input()
    ], GcTextBoxComponent.prototype, "ellipsisString", void 0);
    __decorate([
        Input()
    ], GcTextBoxComponent.prototype, "ellipsis", void 0);
    __decorate([
        Input()
    ], GcTextBoxComponent.prototype, "format", void 0);
    __decorate([
        Input()
    ], GcTextBoxComponent.prototype, "lengthAsByte", void 0);
    __decorate([
        Input()
    ], GcTextBoxComponent.prototype, "maxLength", void 0);
    __decorate([
        Input()
    ], GcTextBoxComponent.prototype, "passwordChar", void 0);
    __decorate([
        Input()
    ], GcTextBoxComponent.prototype, "text", void 0);
    __decorate([
        Input()
    ], GcTextBoxComponent.prototype, "useSystemPasswordChar", void 0);
    __decorate([
        Input(),
        Property("setIMEReadingStringAppend")
    ], GcTextBoxComponent.prototype, "imeReadingStringAppend", void 0);
    __decorate([
        Input(),
        Property("setIMEReadingStringKanaMode")
    ], GcTextBoxComponent.prototype, "imeReadingStringKanaMode", void 0);
    __decorate([
        Input(),
        Property("setIMEReadingStringEnableAlphabetReadingMapping")
    ], GcTextBoxComponent.prototype, "imeReadingStringEnableAlphabetReadingMapping", void 0);
    __decorate([
        Input()
    ], GcTextBoxComponent.prototype, "exitOnLastChar", void 0);
    __decorate([
        Input()
    ], GcTextBoxComponent.prototype, "highlightText", void 0);
    __decorate([
        Input()
    ], GcTextBoxComponent.prototype, "imeReadingString", void 0);
    __decorate([
        Input()
    ], GcTextBoxComponent.prototype, "showClearButton", void 0);
    __decorate([
        Input()
    ], GcTextBoxComponent.prototype, "passwordRevelationMode", void 0);
    __decorate([
        Output()
    ], GcTextBoxComponent.prototype, "onIMEReadingStringOutput", void 0);
    __decorate([
        Output()
    ], GcTextBoxComponent.prototype, "imeReadingStringChange", void 0);
    GcTextBoxComponent = GcTextBoxComponent_1 = __decorate([
        Component({
            selector: 'gc-text-box',
            template: "",
            providers: [provideParent(GcTextBoxComponent_1)]
        })
    ], GcTextBoxComponent);
    return GcTextBoxComponent;
}(GcInputManBaseComponent));
var GcNumberComponent = /** @class */ (function (_super) {
    __extends(GcNumberComponent, _super);
    function GcNumberComponent(ref) {
        var _this = _super.call(this, ref) || this;
        _this.onSpinDown = new EventEmitter();
        _this.onSpinUp = new EventEmitter();
        _this.onInvalidRange = new EventEmitter();
        _this.onValueChanged = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        _this.valueChange = new EventEmitter();
        return _this;
    }
    GcNumberComponent_1 = GcNumberComponent;
    GcNumberComponent.prototype.initGcComponent = function () {
        var element = document.createElement('input');
        this._container.appendChild(element);
        this._imCtrl = new InputMan.GcNumber(element, this);
    };
    GcNumberComponent.prototype.bindEvent = function () {
        var _this = this;
        if (!this._imCtrl) {
            return;
        }
        _super.prototype.bindEvent.call(this);
        this._imCtrl.onSpinDown(function (s) { _this.onSpinDown.emit(s); });
        this._imCtrl.onSpinUp(function (s) { _this.onSpinUp.emit(s); });
        this._imCtrl.onInvalidRange(function (s) { _this.onInvalidRange.emit(s); });
        this._imCtrl.onValueChanged(function (s) {
            _this.onValueChanged.emit(s);
            _this.valueChange.emit(s.getValue());
        });
    };
    GcNumberComponent.prototype.clear = function () {
        return this._imCtrl.clear();
    };
    var GcNumberComponent_1;
    GcNumberComponent.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "value", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "text", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "watermarkZeroText", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "formatDigit", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "displayPositivePrefix", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "displayFormatDigit", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "maxValue", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "minValue", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "positivePrefix", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "positiveSuffix", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "displayPositiveSuffix", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "negativePrefix", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "displayNegativePrefix", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "negativeSuffix", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "displayNegativeSuffix", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "valueSign", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "adjustValueOnFocus", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "allowDeleteToNull", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "clearAction", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "acceptsDecimal", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "currencySymbol", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "decimalPoint", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "maxMinBehavior", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "separator", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "watermarkDisplayZeroText", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "highlightText", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "allowSpin", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "spinWheel", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "spinOnKeys", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "spinWrap", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "showSpinButton", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "spinButtonPosition", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "showNumericPad", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "numericPadPosition", void 0);
    __decorate([
        Input()
    ], GcNumberComponent.prototype, "showClearButton", void 0);
    __decorate([
        Output()
    ], GcNumberComponent.prototype, "onSpinDown", void 0);
    __decorate([
        Output()
    ], GcNumberComponent.prototype, "onSpinUp", void 0);
    __decorate([
        Output()
    ], GcNumberComponent.prototype, "onInvalidRange", void 0);
    __decorate([
        Output()
    ], GcNumberComponent.prototype, "onValueChanged", void 0);
    __decorate([
        Output()
    ], GcNumberComponent.prototype, "valueChange", void 0);
    GcNumberComponent = GcNumberComponent_1 = __decorate([
        Component({
            selector: 'gc-number',
            template: "",
            providers: [provideParent(GcNumberComponent_1)]
        })
    ], GcNumberComponent);
    return GcNumberComponent;
}(GcInputManBaseComponent));
var GcDateTimeComponent = /** @class */ (function (_super) {
    __extends(GcDateTimeComponent, _super);
    function GcDateTimeComponent(ref) {
        var _this = _super.call(this, ref) || this;
        _this.onSpinDown = new EventEmitter();
        _this.onSpinUp = new EventEmitter();
        _this.onInvalidRange = new EventEmitter();
        _this.onInvalidValue = new EventEmitter();
        _this.onNumberChanged = new EventEmitter();
        _this.onValueChanged = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        _this.numberChange = new EventEmitter();
        _this.valueChange = new EventEmitter();
        return _this;
    }
    GcDateTimeComponent_1 = GcDateTimeComponent;
    GcDateTimeComponent.prototype.initGcComponent = function () {
        var element = document.createElement('input');
        this._container.appendChild(element);
        this._imCtrl = new InputMan.GcDateTime(element, this);
    };
    GcDateTimeComponent.prototype.bindEvent = function () {
        var _this = this;
        if (!this._imCtrl) {
            return;
        }
        _super.prototype.bindEvent.call(this);
        this._imCtrl.onSpinDown(function (s) { _this.onSpinDown.emit(s); });
        this._imCtrl.onSpinUp(function (s) { _this.onSpinUp.emit(s); });
        this._imCtrl.onInvalidRange(function (s) { _this.onInvalidRange.emit(s); });
        this._imCtrl.onInvalidValue(function (s) { _this.onInvalidValue.emit(s); });
        this._imCtrl.onNumberChanged(function (s) {
            _this.onNumberChanged.emit(s);
            _this.numberChange.emit(s.getNumber());
        });
        this._imCtrl.onValueChanged(function (s) {
            _this.onValueChanged.emit(s);
            _this.valueChange.emit(s.getValue());
        });
    };
    var GcDateTimeComponent_1;
    GcDateTimeComponent.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "text", void 0);
    __decorate([
        Property("", "", false, false),
        Input()
    ], GcDateTimeComponent.prototype, "number", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "maxDate", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "minDate", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "formatPattern", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "spinIncrement", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "spinOnKeys", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "spinWrap", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "allowSpin", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "spinWheel", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "displayFormatPattern", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "watermarkEmptyEraText", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "promptChar", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "AMDesignator", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "PMDesignator", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "twoDigitYearMax", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "hour12Mode", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "tabAction", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "maxMinBehavior", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "midnightAs24", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "showLiterals", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "adjustValueOnFocus", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "useTwoDigitYearMax", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "validateMode", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "clipContent", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "value", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "watermarkDisplayEmptyEraText", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "dropDownConfig", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "exitOnLastChar", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "highlightText", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "showSpinButton", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "spinButtonPosition", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "showDropDownButton", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "dropDownButtonAlignment", void 0);
    __decorate([
        Input()
    ], GcDateTimeComponent.prototype, "showClearButton", void 0);
    __decorate([
        Output()
    ], GcDateTimeComponent.prototype, "onSpinDown", void 0);
    __decorate([
        Output()
    ], GcDateTimeComponent.prototype, "onSpinUp", void 0);
    __decorate([
        Output()
    ], GcDateTimeComponent.prototype, "onInvalidRange", void 0);
    __decorate([
        Output()
    ], GcDateTimeComponent.prototype, "onInvalidValue", void 0);
    __decorate([
        Output()
    ], GcDateTimeComponent.prototype, "onNumberChanged", void 0);
    __decorate([
        Output()
    ], GcDateTimeComponent.prototype, "onValueChanged", void 0);
    __decorate([
        Output()
    ], GcDateTimeComponent.prototype, "numberChange", void 0);
    __decorate([
        Output()
    ], GcDateTimeComponent.prototype, "valueChange", void 0);
    GcDateTimeComponent = GcDateTimeComponent_1 = __decorate([
        Component({
            selector: 'gc-datetime',
            template: "",
            providers: [provideParent(GcDateTimeComponent_1)]
        })
    ], GcDateTimeComponent);
    return GcDateTimeComponent;
}(GcInputManBaseComponent));
var GcCalendarComponent = /** @class */ (function (_super) {
    __extends(GcCalendarComponent, _super);
    function GcCalendarComponent(ref) {
        var _this = _super.call(this, ref) || this;
        _this.onClickDate = new EventEmitter();
        _this.onScrolled = new EventEmitter();
        _this.onFocusDateChanged = new EventEmitter();
        _this.onSelectedDateChanged = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        _this.focusDateChange = new EventEmitter();
        _this.selectedDateChange = new EventEmitter();
        return _this;
    }
    GcCalendarComponent.prototype.initGcComponent = function () {
        var element = document.createElement('div');
        this._container.appendChild(element);
        if (Array.isArray(this.calendarDimensions)) {
            this.calendarDimensions = {
                width: this.calendarDimensions[0],
                height: this.calendarDimensions[1]
            };
        }
        this._imCtrl = new InputMan.GcCalendar(element, this);
    };
    GcCalendarComponent.prototype.bindEvent = function () {
        var _this = this;
        if (!this._imCtrl) {
            return;
        }
        this._imCtrl.onClickDate(function (s) { _this.onClickDate.emit(s); });
        this._imCtrl.onScrolled(function (s) { _this.onScrolled.emit(s); });
        this._imCtrl.onFocusDateChanged(function (s) {
            _this.onFocusDateChanged.emit(s);
            _this.focusDateChange.emit(s.getFocusDate());
        });
        this._imCtrl.onSelectedDateChanged(function (s) {
            _this.onSelectedDateChanged.emit(s);
            _this.selectedDateChange.emit(s.getSelectedDate());
        });
    };
    GcCalendarComponent.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "visible", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "maxSelectionCount", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "selectionMode", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "selectedDate", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "enabled", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "weekTitleSelect", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "weekNumberSelect", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "focusDate", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "maxDate", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "minDate", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "allowSelection", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "emptyRows", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "firstDayOfWeek", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "firstFiscalMonth", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "firstMonthInView", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "yearMonthFormat", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "headerFormat", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "showZoomButton", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "showRokuyou", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "showHeader", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "showToday", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "showWeekNumber", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "showTrailing", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "calendarYear", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "showNavigator", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "navigatorOrientation", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "overrideTipText", void 0);
    __decorate([
        Input()
    ], GcCalendarComponent.prototype, "calendarType", void 0);
    __decorate([
        Property("setCalendarDimensions", "", true),
        Input()
    ], GcCalendarComponent.prototype, "calendarDimensions", void 0);
    __decorate([
        Output()
    ], GcCalendarComponent.prototype, "onClickDate", void 0);
    __decorate([
        Output()
    ], GcCalendarComponent.prototype, "onScrolled", void 0);
    __decorate([
        Output()
    ], GcCalendarComponent.prototype, "onFocusDateChanged", void 0);
    __decorate([
        Output()
    ], GcCalendarComponent.prototype, "onSelectedDateChanged", void 0);
    __decorate([
        Output()
    ], GcCalendarComponent.prototype, "focusDateChange", void 0);
    __decorate([
        Output()
    ], GcCalendarComponent.prototype, "selectedDateChange", void 0);
    GcCalendarComponent = __decorate([
        Component({
            selector: 'gc-calendar',
            template: ""
        })
    ], GcCalendarComponent);
    return GcCalendarComponent;
}(GcComponents));
var GcMaskComponent = /** @class */ (function (_super) {
    __extends(GcMaskComponent, _super);
    function GcMaskComponent(ref) {
        var _this = _super.call(this, ref) || this;
        _this.onTextChanging = new EventEmitter();
        _this.onSpinDown = new EventEmitter();
        _this.onSpinUp = new EventEmitter();
        _this.onValueChanged = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        _this.valueChange = new EventEmitter();
        _this.valueIsFullChange = new EventEmitter();
        return _this;
    }
    GcMaskComponent_1 = GcMaskComponent;
    GcMaskComponent.prototype.initGcComponent = function () {
        var input = document.createElement('input');
        this._container.appendChild(input);
        this._imCtrl = new InputMan.GcMask(input, this);
    };
    GcMaskComponent.prototype.bindEvent = function () {
        var _this = this;
        if (!this._imCtrl) {
            return;
        }
        _super.prototype.bindEvent.call(this);
        this._imCtrl.onInput(function (s) {
            _this.valueIsFullChange.emit(s.getValueIsFull());
        });
        this._imCtrl.onTextChanging(function (s, e) { _this.onTextChanging.emit({ sender: s, eArgs: e }); });
        this._imCtrl.onSpinDown(function (s) { _this.onSpinDown.emit(s); });
        this._imCtrl.onSpinUp(function (s) { _this.onSpinUp.emit(s); });
        this._imCtrl.onValueChanged(function (s) {
            _this.onValueChanged.emit(s);
            _this.valueChange.emit(s.getValue());
            _this.valueIsFullChange.emit(s.getValueIsFull());
        });
    };
    var GcMaskComponent_1;
    GcMaskComponent.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    __decorate([
        Input()
    ], GcMaskComponent.prototype, "autoConvert", void 0);
    __decorate([
        Input()
    ], GcMaskComponent.prototype, "value", void 0);
    __decorate([
        Input()
    ], GcMaskComponent.prototype, "formatPattern", void 0);
    __decorate([
        Input()
    ], GcMaskComponent.prototype, "promptChar", void 0);
    __decorate([
        Input()
    ], GcMaskComponent.prototype, "showLiterals", void 0);
    __decorate([
        Input()
    ], GcMaskComponent.prototype, "tabAction", void 0);
    __decorate([
        Input()
    ], GcMaskComponent.prototype, "text", void 0);
    __decorate([
        Input()
    ], GcMaskComponent.prototype, "clipContent", void 0);
    __decorate([
        Input()
    ], GcMaskComponent.prototype, "allowSpin", void 0);
    __decorate([
        Input()
    ], GcMaskComponent.prototype, "spinWheel", void 0);
    __decorate([
        Input()
    ], GcMaskComponent.prototype, "spinOnKeys", void 0);
    __decorate([
        Input()
    ], GcMaskComponent.prototype, "exitOnLastChar", void 0);
    __decorate([
        Input()
    ], GcMaskComponent.prototype, "highlightText", void 0);
    __decorate([
        Input()
    ], GcMaskComponent.prototype, "showSpinButton", void 0);
    __decorate([
        Input()
    ], GcMaskComponent.prototype, "spinButtonPosition", void 0);
    __decorate([
        Input()
    ], GcMaskComponent.prototype, "valueIsFull", void 0);
    __decorate([
        Input()
    ], GcMaskComponent.prototype, "showClearButton", void 0);
    __decorate([
        Output()
    ], GcMaskComponent.prototype, "onTextChanging", void 0);
    __decorate([
        Output()
    ], GcMaskComponent.prototype, "onSpinDown", void 0);
    __decorate([
        Output()
    ], GcMaskComponent.prototype, "onSpinUp", void 0);
    __decorate([
        Output()
    ], GcMaskComponent.prototype, "onValueChanged", void 0);
    __decorate([
        Output()
    ], GcMaskComponent.prototype, "valueChange", void 0);
    __decorate([
        Output()
    ], GcMaskComponent.prototype, "valueIsFullChange", void 0);
    GcMaskComponent = GcMaskComponent_1 = __decorate([
        Component({
            selector: 'gc-mask',
            template: "",
            providers: [provideParent(GcMaskComponent_1)]
        })
    ], GcMaskComponent);
    return GcMaskComponent;
}(GcInputManBaseComponent));
var GcListBoxColumnComponent = /** @class */ (function () {
    function GcListBoxColumnComponent() {
    }
    __decorate([
        Input()
    ], GcListBoxColumnComponent.prototype, "name", void 0);
    __decorate([
        Input()
    ], GcListBoxColumnComponent.prototype, "label", void 0);
    __decorate([
        Input()
    ], GcListBoxColumnComponent.prototype, "width", void 0);
    __decorate([
        Input()
    ], GcListBoxColumnComponent.prototype, "isValuePath", void 0);
    __decorate([
        Input()
    ], GcListBoxColumnComponent.prototype, "visible", void 0);
    __decorate([
        Input()
    ], GcListBoxColumnComponent.prototype, "clickSort", void 0);
    __decorate([
        Input()
    ], GcListBoxColumnComponent.prototype, "contentAlignment", void 0);
    __decorate([
        Input()
    ], GcListBoxColumnComponent.prototype, "headerAlignment", void 0);
    __decorate([
        Input()
    ], GcListBoxColumnComponent.prototype, "showTip", void 0);
    GcListBoxColumnComponent = __decorate([
        Component({
            selector: 'gc-list-box-column',
            template: ""
        })
    ], GcListBoxColumnComponent);
    return GcListBoxColumnComponent;
}());
var GcListBoxComponent = /** @class */ (function (_super) {
    __extends(GcListBoxComponent, _super);
    function GcListBoxComponent(ref) {
        var _this = _super.call(this, ref) || this;
        _this.checkedChanged = new EventEmitter();
        _this.selectedChanged = new EventEmitter();
        _this.focusedChanged = new EventEmitter();
        _this.itemClick = new EventEmitter();
        _this.loadComplete = new EventEmitter();
        _this.itemsChanged = new EventEmitter();
        _this.selectedIndexChange = new EventEmitter();
        _this.checkedIndexChange = new EventEmitter();
        _this.selectedIndicesChange = new EventEmitter();
        _this.checkedIndicesChange = new EventEmitter();
        return _this;
    }
    GcListBoxComponent.prototype.initGcComponent = function () {
        var _this = this;
        if (this.columnComponents && this.columnComponents.length > 0) {
            this.columns = [];
            this.columnComponents.forEach(function (column) {
                _this.columns.push({
                    name: column.name,
                    label: column.label,
                    width: column.width,
                    isValuePath: column.isValuePath,
                    visible: column.visible,
                    clickSort: column.clickSort,
                    contentAlignment: column.contentAlignment,
                    headerAlignment: column.headerAlignment,
                    showTip: column.showTip
                });
            });
        }
        var element = document.createElement('select');
        this._container.appendChild(element);
        this._imCtrl = new InputMan.GcListBox(element, this);
    };
    GcListBoxComponent.prototype.bindEvent = function () {
        var _this = this;
        if (!this._imCtrl) {
            return;
        }
        this._imCtrl.addEventListener(InputMan.GcListBoxEvent.CheckedChanged, function (eventArgs) {
            _this.checkedChanged.emit(eventArgs);
            _this.checkedIndexChange.emit(_this._imCtrl.getCheckedIndices()[0]);
            _this.checkedIndicesChange.emit(_this._imCtrl.getCheckedIndices());
        });
        this._imCtrl.addEventListener(InputMan.GcListBoxEvent.SelectedChanged, function (eventArgs) {
            _this.selectedChanged.emit(eventArgs);
            _this.selectedIndexChange.emit(_this._imCtrl.getSelectedIndex());
            _this.selectedIndicesChange.emit(_this._imCtrl.getSelectedIndices());
        });
        this._imCtrl.addEventListener(InputMan.GcListBoxEvent.FocusedChanged, function (eventArgs) {
            _this.focusedChanged.emit(eventArgs);
        });
        this._imCtrl.addEventListener(InputMan.GcListBoxEvent.ItemClick, function (sender, eventArgs) {
            _this.itemClick.emit({ sender: sender, eArgs: eventArgs });
        });
        this._imCtrl.addEventListener(InputMan.GcListBoxEvent.LoadComplete, function (eventArgs) {
            _this.loadComplete.emit(eventArgs);
        });
        this._imCtrl.addEventListener(InputMan.GcListBoxEvent.ItemsChanged, function (eventArgs) {
            _this.itemsChanged.emit(eventArgs);
        });
    };
    GcListBoxComponent.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "items", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "columns", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "virtualMode", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "allowResize", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "selectionMode", void 0);
    __decorate([
        Input(),
        Property("", "", false, false)
    ], GcListBoxComponent.prototype, "selectedIndex", void 0);
    __decorate([
        Input(),
        Property("", "", false, false)
    ], GcListBoxComponent.prototype, "checkedIndex", void 0);
    __decorate([
        Input(),
        Property("", "", false, false)
    ], GcListBoxComponent.prototype, "selectedIndices", void 0);
    __decorate([
        Input(),
        Property("", "", false, false)
    ], GcListBoxComponent.prototype, "checkedIndices", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "allowColumnResize", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "overflow", void 0);
    __decorate([
        Property("resizeWidth"),
        Input()
    ], GcListBoxComponent.prototype, "width", void 0);
    __decorate([
        Property("resizeHeight"),
        Input()
    ], GcListBoxComponent.prototype, "height", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "itemHeight", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "checkOnClick", void 0);
    __decorate([
        Property('setVisibleItemCount'),
        Input()
    ], GcListBoxComponent.prototype, "visibleItems", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "visible", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "enabled", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "showTip", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "multiColumn", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "colHeaderHeight", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "showHeader", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "valueMemberPath", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "displayMemberPath", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "showCheckBox", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "itemTemplate", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "headerTemplate", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "footerTemplate", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "emptyTemplate", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "load", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "pageSize", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "generatingItem", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "selectTemplate", void 0);
    __decorate([
        Input()
    ], GcListBoxComponent.prototype, "formatItem", void 0);
    __decorate([
        Output()
    ], GcListBoxComponent.prototype, "checkedChanged", void 0);
    __decorate([
        Output()
    ], GcListBoxComponent.prototype, "selectedChanged", void 0);
    __decorate([
        Output()
    ], GcListBoxComponent.prototype, "focusedChanged", void 0);
    __decorate([
        Output()
    ], GcListBoxComponent.prototype, "itemClick", void 0);
    __decorate([
        Output()
    ], GcListBoxComponent.prototype, "loadComplete", void 0);
    __decorate([
        Output()
    ], GcListBoxComponent.prototype, "itemsChanged", void 0);
    __decorate([
        Output()
    ], GcListBoxComponent.prototype, "selectedIndexChange", void 0);
    __decorate([
        Output()
    ], GcListBoxComponent.prototype, "checkedIndexChange", void 0);
    __decorate([
        Output()
    ], GcListBoxComponent.prototype, "selectedIndicesChange", void 0);
    __decorate([
        Output()
    ], GcListBoxComponent.prototype, "checkedIndicesChange", void 0);
    __decorate([
        ContentChildren(GcListBoxColumnComponent)
    ], GcListBoxComponent.prototype, "columnComponents", void 0);
    GcListBoxComponent = __decorate([
        Component({
            selector: 'gc-list-box',
            template: ""
        })
    ], GcListBoxComponent);
    return GcListBoxComponent;
}(GcComponents));
var GcComboBoxColumnComponent = /** @class */ (function () {
    function GcComboBoxColumnComponent() {
    }
    __decorate([
        Input()
    ], GcComboBoxColumnComponent.prototype, "name", void 0);
    __decorate([
        Input()
    ], GcComboBoxColumnComponent.prototype, "label", void 0);
    __decorate([
        Input()
    ], GcComboBoxColumnComponent.prototype, "width", void 0);
    __decorate([
        Input()
    ], GcComboBoxColumnComponent.prototype, "isValuePath", void 0);
    __decorate([
        Input()
    ], GcComboBoxColumnComponent.prototype, "visible", void 0);
    __decorate([
        Input()
    ], GcComboBoxColumnComponent.prototype, "clickSort", void 0);
    __decorate([
        Input()
    ], GcComboBoxColumnComponent.prototype, "contentAlignment", void 0);
    __decorate([
        Input()
    ], GcComboBoxColumnComponent.prototype, "headerAlignment", void 0);
    __decorate([
        Input()
    ], GcComboBoxColumnComponent.prototype, "showTip", void 0);
    GcComboBoxColumnComponent = __decorate([
        Component({
            selector: 'gc-combo-box-column',
            template: ""
        })
    ], GcComboBoxColumnComponent);
    return GcComboBoxColumnComponent;
}());
var GcComboBoxComponent = /** @class */ (function (_super) {
    __extends(GcComboBoxComponent, _super);
    function GcComboBoxComponent(ref) {
        var _this = _super.call(this, ref) || this;
        _this.selectedChanged = new EventEmitter();
        _this.checkedChanged = new EventEmitter();
        _this.dropDownClosed = new EventEmitter();
        _this.dropDownOpened = new EventEmitter();
        _this.textChanged = new EventEmitter();
        _this.spinDown = new EventEmitter();
        _this.spinUp = new EventEmitter();
        _this.itemsChanged = new EventEmitter();
        _this.itemsChange = new EventEmitter();
        _this.selectedValueChange = new EventEmitter();
        _this.selectedIndexChange = new EventEmitter();
        _this.checkedValuesChange = new EventEmitter();
        _this.selectedItemChange = new EventEmitter();
        _this.checkedItemsChange = new EventEmitter();
        _this.checkedIndicesChange = new EventEmitter();
        return _this;
    }
    GcComboBoxComponent_1 = GcComboBoxComponent;
    GcComboBoxComponent.prototype.initGcComponent = function () {
        var _this = this;
        if (this.columnComponents && this.columnComponents.length > 0) {
            this.columns = [];
            this.columnComponents.forEach(function (column) {
                _this.columns.push({
                    name: column.name,
                    label: column.label,
                    width: column.width,
                    isValuePath: column.isValuePath,
                    visible: column.visible,
                    clickSort: column.clickSort,
                    contentAlignment: column.contentAlignment,
                    headerAlignment: column.headerAlignment,
                    showTip: column.showTip
                });
            });
        }
        var element = document.createElement('select');
        this._container.appendChild(element);
        this._imCtrl = new InputMan.GcComboBox(element, this);
    };
    GcComboBoxComponent.prototype.bindEvent = function () {
        var _this = this;
        if (!this._imCtrl) {
            return;
        }
        this._imCtrl.addEventListener(InputMan.GcComboBoxEvent.SelectedChanged, function (eventArgs) {
            _this.selectedChanged.emit(eventArgs);
            _this.selectedValueChange.emit(_this._imCtrl.getSelectedValue());
            _this.selectedIndexChange.emit(_this._imCtrl.getSelectedIndex());
            _this.selectedItemChange.emit(_this._imCtrl.getSelectedItem());
        });
        this._imCtrl.addEventListener(InputMan.GcComboBoxEvent.CheckedChanged, function (eventArgs) {
            _this.checkedChanged.emit(eventArgs);
            _this.checkedValuesChange.emit(_this._imCtrl.getCheckedValues());
            _this.checkedItemsChange.emit(_this._imCtrl.getCheckedItems());
            _this.checkedIndicesChange.emit(_this._imCtrl.getCheckedIndices());
        });
        this._imCtrl.addEventListener(InputMan.GcComboBoxEvent.DropDownClosed, function (eventArgs) {
            _this.dropDownClosed.emit(eventArgs);
        });
        this._imCtrl.addEventListener(InputMan.GcComboBoxEvent.DropDownOpened, function (eventArgs) {
            _this.dropDownOpened.emit(eventArgs);
        });
        this._imCtrl.addEventListener(InputMan.GcComboBoxEvent.TextChanged, function (eventArgs) {
            _this.textChanged.emit(eventArgs);
        });
        this._imCtrl.addEventListener(InputMan.GcComboBoxEvent.SpinDown, function (eventArgs) {
            _this.spinDown.emit(eventArgs);
        });
        this._imCtrl.addEventListener(InputMan.GcComboBoxEvent.SpinUp, function (eventArgs) {
            _this.spinUp.emit(eventArgs);
        });
        this._imCtrl.addEventListener(InputMan.GcComboBoxEvent.ItemsChanged, function (eventArgs) {
            _this.itemsChanged.emit(eventArgs);
            _this.itemsChange.emit(_this._imCtrl.getItems());
        });
    };
    var GcComboBoxComponent_1;
    GcComboBoxComponent.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "items", void 0);
    __decorate([
        Input(),
        Property("", "", false, false)
    ], GcComboBoxComponent.prototype, "selectedValue", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "allowDropDownResize", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "readOnly", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "autoSelect", void 0);
    __decorate([
        Input(),
        Property("", "", false, false)
    ], GcComboBoxComponent.prototype, "selectedIndex", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "autoFilter", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "visible", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "enabled", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "showTip", void 0);
    __decorate([
        Property("setEditable"),
        Input()
    ], GcComboBoxComponent.prototype, "isEditable", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "watermarkDisplayNullText", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "watermarkNullText", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "highlightText", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "exitOnEnterKey", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "useClipboard", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "acceptsCrlf", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "ellipsis", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "ellipsisString", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "exitOnLeftRightKey", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "editMode", void 0);
    __decorate([
        Input(),
        Property("", "", false, false)
    ], GcComboBoxComponent.prototype, "checkedValues", void 0);
    __decorate([
        Input(),
        Property("", "", false, false)
    ], GcComboBoxComponent.prototype, "selectedItem", void 0);
    __decorate([
        Input(),
        Property("", "", false, false)
    ], GcComboBoxComponent.prototype, "checkedItems", void 0);
    __decorate([
        Input(),
        Property("", "", false, false)
    ], GcComboBoxComponent.prototype, "checkedIndices", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "showDropDownButton", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "dropDownButtonPosition", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "showSpinButton", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "spinButtonPosition", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "dropDownWidth", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "dropDownHeight", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "minPrefixLength", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "isMultiSelect", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "dropDownOverflow", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "visibleItems", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "itemHeight", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "columns", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "showHeader", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "valueMemberPath", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "displayMemberPath", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "checkOnClick", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "itemTemplate", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "headerTemplate", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "footerTemplate", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "spinWheel", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "emptyTemplate", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "load", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "pageSize", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "virtualMode", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "generatingItem", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "selectTemplate", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "formatItem", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "allowColumnResize", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "colHeaderHeight", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "container", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "autoDropDown", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "dropDownButtonVisible", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "showClearButton", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "autoScale", void 0);
    __decorate([
        Input()
    ], GcComboBoxComponent.prototype, "minScaleFactor", void 0);
    __decorate([
        Output()
    ], GcComboBoxComponent.prototype, "selectedChanged", void 0);
    __decorate([
        Output()
    ], GcComboBoxComponent.prototype, "checkedChanged", void 0);
    __decorate([
        Output()
    ], GcComboBoxComponent.prototype, "dropDownClosed", void 0);
    __decorate([
        Output()
    ], GcComboBoxComponent.prototype, "dropDownOpened", void 0);
    __decorate([
        Output()
    ], GcComboBoxComponent.prototype, "textChanged", void 0);
    __decorate([
        Output()
    ], GcComboBoxComponent.prototype, "spinDown", void 0);
    __decorate([
        Output()
    ], GcComboBoxComponent.prototype, "spinUp", void 0);
    __decorate([
        Output()
    ], GcComboBoxComponent.prototype, "itemsChanged", void 0);
    __decorate([
        Output()
    ], GcComboBoxComponent.prototype, "itemsChange", void 0);
    __decorate([
        Output()
    ], GcComboBoxComponent.prototype, "selectedValueChange", void 0);
    __decorate([
        Output()
    ], GcComboBoxComponent.prototype, "selectedIndexChange", void 0);
    __decorate([
        Output()
    ], GcComboBoxComponent.prototype, "checkedValuesChange", void 0);
    __decorate([
        Output()
    ], GcComboBoxComponent.prototype, "selectedItemChange", void 0);
    __decorate([
        Output()
    ], GcComboBoxComponent.prototype, "checkedItemsChange", void 0);
    __decorate([
        Output()
    ], GcComboBoxComponent.prototype, "checkedIndicesChange", void 0);
    __decorate([
        ContentChildren(GcComboBoxColumnComponent)
    ], GcComboBoxComponent.prototype, "columnComponents", void 0);
    GcComboBoxComponent = GcComboBoxComponent_1 = __decorate([
        Component({
            selector: 'gc-combo-box',
            template: "",
            providers: [provideParent(GcComboBoxComponent_1)]
        })
    ], GcComboBoxComponent);
    return GcComboBoxComponent;
}(GcComponents));
var GcDateTimePickerComponent = /** @class */ (function (_super) {
    __extends(GcDateTimePickerComponent, _super);
    function GcDateTimePickerComponent(ref) {
        var _this = _super.call(this, ref) || this;
        _this.selectedDateChanged = new EventEmitter();
        _this.selectedValueChange = new EventEmitter();
        return _this;
    }
    GcDateTimePickerComponent.prototype.initGcComponent = function () {
        var element = document.createElement('div');
        this._container.appendChild(element);
        this._imCtrl = new InputMan.GcDateTimePicker(element, this);
    };
    GcDateTimePickerComponent.prototype.bindEvent = function () {
        var _this = this;
        if (!this._imCtrl) {
            return;
        }
        this._imCtrl.addEventListener(InputMan.GcDateTimePickerEvent.SelectedDateChanged, function (sender, eventArgs) {
            _this.selectedDateChanged.emit({ sender: sender, eArgs: eventArgs });
            _this.selectedValueChange.emit(_this._imCtrl.getValue());
        });
    };
    GcDateTimePickerComponent.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    __decorate([
        Property("setValue"),
        Input()
    ], GcDateTimePickerComponent.prototype, "selectedValue", void 0);
    __decorate([
        Input()
    ], GcDateTimePickerComponent.prototype, "maxDate", void 0);
    __decorate([
        Input()
    ], GcDateTimePickerComponent.prototype, "minDate", void 0);
    __decorate([
        Property('setPickerType'),
        Input()
    ], GcDateTimePickerComponent.prototype, "type", void 0);
    __decorate([
        Input()
    ], GcDateTimePickerComponent.prototype, "minuteInterval", void 0);
    __decorate([
        Input()
    ], GcDateTimePickerComponent.prototype, "secondsInterval", void 0);
    __decorate([
        Input()
    ], GcDateTimePickerComponent.prototype, "visible", void 0);
    __decorate([
        Property('showSeconds', "", false, false),
        Input()
    ], GcDateTimePickerComponent.prototype, "hasSeconds", void 0);
    __decorate([
        Property('showMidnightAs24', "", false, false),
        Input()
    ], GcDateTimePickerComponent.prototype, "showMidnightAs24", void 0);
    __decorate([
        Input()
    ], GcDateTimePickerComponent.prototype, "yearFormat", void 0);
    __decorate([
        Input()
    ], GcDateTimePickerComponent.prototype, "monthFormat", void 0);
    __decorate([
        Input()
    ], GcDateTimePickerComponent.prototype, "dayFormat", void 0);
    __decorate([
        Output()
    ], GcDateTimePickerComponent.prototype, "selectedDateChanged", void 0);
    __decorate([
        Output()
    ], GcDateTimePickerComponent.prototype, "selectedValueChange", void 0);
    GcDateTimePickerComponent = __decorate([
        Component({
            selector: 'gc-datetime-picker',
            template: ""
        })
    ], GcDateTimePickerComponent);
    return GcDateTimePickerComponent;
}(GcComponents));
var GcTipNotifierComponent = /** @class */ (function (_super) {
    __extends(GcTipNotifierComponent, _super);
    function GcTipNotifierComponent(ref, _parent) {
        var _this = _super.call(this, ref) || this;
        _this._parent = _parent;
        return _this;
    }
    GcTipNotifierComponent.prototype.ngAfterViewInit = function () {
        if (!this._parent || typeof this._parent !== 'object' ||
            typeof this._parent.getNestedIMControl() !== 'object') {
            return;
        }
        this._imCtrl = new InputMan.GcTipNotifier(this._parent.getNestedIMControl(), this);
        this.onInitialized.emit(this._imCtrl);
    };
    GcTipNotifierComponent.prototype.bindEvent = function () { };
    GcTipNotifierComponent.prototype.initGcComponent = function () {
    };
    GcTipNotifierComponent.prototype.onFail = function () {
        return this._imCtrl.onFail();
    };
    GcTipNotifierComponent.prototype.onSuccess = function () {
        return this._imCtrl.onSuccess();
    };
    GcTipNotifierComponent.prototype.onClear = function () {
        return this._imCtrl.onClear();
    };
    GcTipNotifierComponent.ctorParameters = function () { return [
        { type: ElementRef },
        { type: GcComponents, decorators: [{ type: Optional }] }
    ]; };
    __decorate([
        Input()
    ], GcTipNotifierComponent.prototype, "direction", void 0);
    __decorate([
        Input()
    ], GcTipNotifierComponent.prototype, "position", void 0);
    __decorate([
        Input()
    ], GcTipNotifierComponent.prototype, "directionPriority", void 0);
    __decorate([
        Input()
    ], GcTipNotifierComponent.prototype, "template", void 0);
    __decorate([
        Input()
    ], GcTipNotifierComponent.prototype, "failMessage", void 0);
    __decorate([
        Input()
    ], GcTipNotifierComponent.prototype, "successMessage", void 0);
    __decorate([
        Input()
    ], GcTipNotifierComponent.prototype, "tipState", void 0);
    GcTipNotifierComponent = __decorate([
        Component({
            selector: 'gc-tip-notifier',
            template: ""
        }),
        __param(1, Optional())
    ], GcTipNotifierComponent);
    return GcTipNotifierComponent;
}(GcComponents));
var GcIconNotifierComponent = /** @class */ (function (_super) {
    __extends(GcIconNotifierComponent, _super);
    function GcIconNotifierComponent(ref, _parent) {
        var _this = _super.call(this, ref) || this;
        _this._parent = _parent;
        return _this;
    }
    GcIconNotifierComponent.prototype.ngAfterViewInit = function () {
        if (!this._parent || typeof this._parent !== 'object' ||
            typeof this._parent.getNestedIMControl() !== 'object') {
            return;
        }
        this._imCtrl = new InputMan.GcIconNotifier(this._parent.getNestedIMControl(), this);
        this.onInitialized.emit(this._imCtrl);
    };
    GcIconNotifierComponent.prototype.bindEvent = function () { };
    GcIconNotifierComponent.prototype.initGcComponent = function () {
    };
    GcIconNotifierComponent.prototype.onFail = function () {
        return this._imCtrl.onFail();
    };
    GcIconNotifierComponent.prototype.onSuccess = function () {
        return this._imCtrl.onSuccess();
    };
    GcIconNotifierComponent.prototype.onClear = function () {
        return this._imCtrl.onClear();
    };
    GcIconNotifierComponent.ctorParameters = function () { return [
        { type: ElementRef },
        { type: GcComponents, decorators: [{ type: Optional }] }
    ]; };
    __decorate([
        Input()
    ], GcIconNotifierComponent.prototype, "direction", void 0);
    __decorate([
        Property('setFailIconSrc'),
        Input()
    ], GcIconNotifierComponent.prototype, "failIcon", void 0);
    __decorate([
        Property('setSuccessIconSrc'),
        Input()
    ], GcIconNotifierComponent.prototype, "successIcon", void 0);
    __decorate([
        Input()
    ], GcIconNotifierComponent.prototype, "failMessage", void 0);
    __decorate([
        Input()
    ], GcIconNotifierComponent.prototype, "successMessage", void 0);
    GcIconNotifierComponent = __decorate([
        Component({
            selector: 'gc-icon-notifier',
            template: ""
        }),
        __param(1, Optional())
    ], GcIconNotifierComponent);
    return GcIconNotifierComponent;
}(GcComponents));
var GcMultilineTextBoxComponent = /** @class */ (function (_super) {
    __extends(GcMultilineTextBoxComponent, _super);
    function GcMultilineTextBoxComponent(ref) {
        var _this = _super.call(this, ref) || this;
        _this.onEditStatusChanged = new EventEmitter();
        _this.onInvalidInput = new EventEmitter();
        _this.onKeyExit = new EventEmitter();
        _this.onTextChanged = new EventEmitter();
        _this.onIMEReadingStringOutput = new EventEmitter();
        _this.textChange = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        _this.imeReadingStringChange = new EventEmitter();
        return _this;
    }
    GcMultilineTextBoxComponent_1 = GcMultilineTextBoxComponent;
    GcMultilineTextBoxComponent.prototype.initGcComponent = function () {
        var element = document.createElement('textarea');
        this._container.appendChild(element);
        this["IMEReadingStringAppend"] = this.imeReadingStringAppend;
        this["IMEReadingStringKanaMode"] = this.imeReadingStringKanaMode;
        this["IMEReadingStringEnableAlphabetReadingMapping"] = this.imeReadingStringEnableAlphabetReadingMapping;
        this._imCtrl = new InputMan.GcMultiLineTextBox(element, this);
    };
    GcMultilineTextBoxComponent.prototype.bindEvent = function () {
        var _this = this;
        if (!this._imCtrl) {
            return;
        }
        _super.prototype.bindEvent.call(this);
        this._imCtrl.onIMEReadingStringOutput(function (eventArgs) {
            _this.onIMEReadingStringOutput.emit(eventArgs);
            _this.imeReadingStringChange.emit(_this._imCtrl.getIMEReadingString());
        });
    };
    var GcMultilineTextBoxComponent_1;
    GcMultilineTextBoxComponent.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    __decorate([
        Input()
    ], GcMultilineTextBoxComponent.prototype, "countWrappedLine", void 0);
    __decorate([
        Input()
    ], GcMultilineTextBoxComponent.prototype, "lengthAsByte", void 0);
    __decorate([
        Input()
    ], GcMultilineTextBoxComponent.prototype, "maxLength", void 0);
    __decorate([
        Input()
    ], GcMultilineTextBoxComponent.prototype, "maxLineCount", void 0);
    __decorate([
        Input(),
        Property("setIMEReadingStringKanaMode")
    ], GcMultilineTextBoxComponent.prototype, "imeReadingStringKanaMode", void 0);
    __decorate([
        Input()
    ], GcMultilineTextBoxComponent.prototype, "scrollBarMode", void 0);
    __decorate([
        Input()
    ], GcMultilineTextBoxComponent.prototype, "scrollBars", void 0);
    __decorate([
        Input()
    ], GcMultilineTextBoxComponent.prototype, "wordWrap", void 0);
    __decorate([
        Input()
    ], GcMultilineTextBoxComponent.prototype, "acceptsReturn", void 0);
    __decorate([
        Input()
    ], GcMultilineTextBoxComponent.prototype, "acceptsTab", void 0);
    __decorate([
        Input(),
        Property("setIMEReadingStringAppend")
    ], GcMultilineTextBoxComponent.prototype, "imeReadingStringAppend", void 0);
    __decorate([
        Input()
    ], GcMultilineTextBoxComponent.prototype, "height", void 0);
    __decorate([
        Input(),
        Property("setIMEReadingStringEnableAlphabetReadingMapping")
    ], GcMultilineTextBoxComponent.prototype, "imeReadingStringEnableAlphabetReadingMapping", void 0);
    __decorate([
        Input()
    ], GcMultilineTextBoxComponent.prototype, "exitOnLastChar", void 0);
    __decorate([
        Input()
    ], GcMultilineTextBoxComponent.prototype, "highlightText", void 0);
    __decorate([
        Input()
    ], GcMultilineTextBoxComponent.prototype, "format", void 0);
    __decorate([
        Input()
    ], GcMultilineTextBoxComponent.prototype, "autoConvert", void 0);
    __decorate([
        Input()
    ], GcMultilineTextBoxComponent.prototype, "text", void 0);
    __decorate([
        Input()
    ], GcMultilineTextBoxComponent.prototype, "lines", void 0);
    __decorate([
        Input()
    ], GcMultilineTextBoxComponent.prototype, "imeReadingString", void 0);
    __decorate([
        Output()
    ], GcMultilineTextBoxComponent.prototype, "onEditStatusChanged", void 0);
    __decorate([
        Output()
    ], GcMultilineTextBoxComponent.prototype, "onInvalidInput", void 0);
    __decorate([
        Output()
    ], GcMultilineTextBoxComponent.prototype, "onKeyExit", void 0);
    __decorate([
        Output()
    ], GcMultilineTextBoxComponent.prototype, "onTextChanged", void 0);
    __decorate([
        Output()
    ], GcMultilineTextBoxComponent.prototype, "onIMEReadingStringOutput", void 0);
    __decorate([
        Output()
    ], GcMultilineTextBoxComponent.prototype, "textChange", void 0);
    __decorate([
        Output()
    ], GcMultilineTextBoxComponent.prototype, "imeReadingStringChange", void 0);
    GcMultilineTextBoxComponent = GcMultilineTextBoxComponent_1 = __decorate([
        Component({
            selector: 'gc-multiline-textbox',
            template: "",
            providers: [provideParent(GcMultilineTextBoxComponent_1)]
        })
    ], GcMultilineTextBoxComponent);
    return GcMultilineTextBoxComponent;
}(GcInputManBaseComponent));

/**
 *  Declare & add export modules
 */
var InputManModule = /** @class */ (function () {
    function InputManModule() {
    }
    InputManModule = __decorate([
        NgModule({
            imports: [
                CommonModule,
                FormsModule
            ],
            declarations: [
                GcMaskComponent,
                GcTextBoxComponent,
                GcCalendarComponent,
                GcNumberComponent,
                GcDateTimeComponent,
                GcListBoxComponent,
                GcComboBoxComponent,
                GcDateTimePickerComponent,
                GcTipNotifierComponent,
                GcIconNotifierComponent,
                GcMultilineTextBoxComponent,
                GcComboBoxColumnComponent,
                GcListBoxColumnComponent
            ],
            exports: [
                GcMaskComponent,
                GcTextBoxComponent,
                GcCalendarComponent,
                GcNumberComponent,
                GcDateTimeComponent,
                GcListBoxComponent,
                GcComboBoxComponent,
                GcDateTimePickerComponent,
                GcTipNotifierComponent,
                GcIconNotifierComponent,
                GcMultilineTextBoxComponent,
                GcComboBoxColumnComponent,
                GcListBoxColumnComponent
            ]
        })
    ], InputManModule);
    return InputManModule;
}());

/**
 * Generated bundle index. Do not edit.
 */

export { GcCalendarComponent, GcComboBoxColumnComponent, GcComboBoxComponent, GcComponents, GcDateTimeComponent, GcDateTimePickerComponent, GcIconNotifierComponent, GcInputManBaseComponent, GcListBoxColumnComponent, GcListBoxComponent, GcMaskComponent, GcMultilineTextBoxComponent, GcNumberComponent, GcTextBoxComponent, GcTipNotifierComponent, InputManModule, MethodType, Property, provideParent, ɵ0, ɵ1 };
//# sourceMappingURL=grapecity-inputman.angular.js.map
